@@ -39,17 +39,31 @@ def get_structures(ranking, base_path="."):
     return structures
 
 
-def get_restraints(restraints_file):
+def get_restraints(restraints_file, include_passive=False, only_passive=False):
     restraints_receptor = set()
     restraints_ligand = set()
     with open(restraints_file) as handle:
         for line in handle:
             line = line.rstrip(os.linesep)
             if line:
-                if line.startswith("R"):
-                    restraints_receptor.add(line)
-                if line.startswith("L"):
-                    restraints_ligand.add(line)
+                if only_passive:
+                    if line.startswith("R") and line.endswith("P"):
+                        restraints_receptor.add(line)
+                    if line.startswith("L") and line.endswith("P"):
+                        restraints_ligand.add(line)
+                else:
+                    if line.startswith("R"):
+                        if line.endswith("P"):
+                            if include_passive:
+                                restraints_receptor.add(line)
+                        else:
+                            restraints_receptor.add(line)
+                    else:
+                        if line.endswith("P"):
+                            if include_passive:
+                                restraints_ligand.add(line)
+                        else:
+                            restraints_ligand.add(line)
     return restraints_receptor, restraints_ligand
 
 
@@ -102,6 +116,22 @@ def parse_command_line():
         action="store_true",
         default=False,
     )
+    parser.add_argument(
+        "--include_passive",
+        "-include_passive",
+        help="Include passive restraints into filtering",
+        dest="include_passive",
+        action="store_true",
+        default=False,
+    )
+    parser.add_argument(
+        "--only_passive",
+        "-only_passive",
+        help="Filter only by passive restraints",
+        dest="only_passive",
+        action="store_true",
+        default=False,
+    )
 
     return parser.parse_args()
 
@@ -111,6 +141,11 @@ if __name__ == "__main__":
     # Parse command line
     args = parse_command_line()
 
+    # Check that --include_passive and --only_passive are not defined simultaneously
+    if args.include_passive and args.only_passive:
+        log.error("--include_passive and --only_passive are mutually exclusive")
+        raise SystemExit
+
     log.info("Calculating interface at {:3.1f}A".format(args.cutoff))
 
     # Get ranking
@@ -120,7 +155,9 @@ if __name__ == "__main__":
     base_path = os.path.abspath(os.path.dirname(args.ranking_file))
     structures = get_structures(ranking, base_path)
 
-    restraints_receptor, restraints_ligand = get_restraints(args.restraints_file)
+    restraints_receptor, restraints_ligand = get_restraints(
+        args.restraints_file, args.include_passive, args.only_passive
+    )
 
     # Total number of restraints to be satisfied
     total = float(len(restraints_receptor) + len(restraints_ligand))
@@ -144,23 +181,23 @@ if __name__ == "__main__":
 
             # Read molecule and split by receptor and ligand
             if score > 0.0:
+                rec_chains = [
+                    chain.strip() for chain in args.receptor_chains.split(",")
+                ]
+                rec_chains_rst = " ".join(rec_chains)
+                lig_chains = [chain.strip() for chain in args.ligand_chains.split(",")]
+                lig_chains_rst = " ".join(lig_chains)
+
                 molecule = parsePDB(pdb)
+
                 if args.rnuc:
-                    receptor = molecule.select(
-                        "nucleic and chain {}".format(args.receptor_chains)
-                    )
+                    receptor = molecule.select(f"nucleic and (chain {rec_chains_rst})")
                 else:
-                    receptor = molecule.select(
-                        "protein and chain {}".format(args.receptor_chains)
-                    )
+                    receptor = molecule.select(f"protein and (chain {rec_chains_rst})")
                 if args.lnuc:
-                    ligand = molecule.select(
-                        "nucleic and chain {}".format(args.ligand_chains)
-                    )
+                    ligand = molecule.select(f"nucleic and (chain {lig_chains_rst})")
                 else:
-                    ligand = molecule.select(
-                        "protein and chain {}".format(args.ligand_chains)
-                    )
+                    ligand = molecule.select(f"protein and (chain {lig_chains_rst})")
 
                 # Contacts on receptor side
                 protein_contacts = Contacts(receptor)
