@@ -4,11 +4,11 @@ import os
 
 class RegressionTest(object):
     def __init__(self):
-        self.path = ''
-        self.test_path = ''
-        self.golden_data_path = ''
+        self.path = None
+        self.test_path = None
+        self.golden_data_path = None
 
-    def ini_test_path(self):
+    def ini_path(self):
         try:
             if self.test_path:
                 shutil.rmtree(self.test_path)
@@ -16,7 +16,7 @@ class RegressionTest(object):
             pass
         os.mkdir(self.test_path)
 
-    def clean_test_path(self):
+    def clean_path(self):
         try:
             shutil.rmtree(self.test_path)
         except OSError:
