@@ -21,7 +21,8 @@ class TestSetupWithRestraints(RegressionTest):
         shutil.copy(self.golden_data_path / "restraints.list", self.test_path)
 
     def teardown(self):
-        self.clean_path()
+        #self.clean_path()
+        pass
 
     def test_lightdock_setup_automatic(self):
         os.chdir(self.test_path)
@@ -101,3 +102,39 @@ class TestSetupWithRestraintsAndInsertCodes(RegressionTest):
             self.golden_data_path / "lightdock_ligand.pdb",
             self.test_path / "lightdock_ligand.pdb",
         )
+
+
+class TestSetupWithRestraintsAndFlipMode(RegressionTest):
+    def __init__(self):
+        super().__init__()
+        self.path = Path(__file__).absolute().parent
+        self.test_path = self.path / "scratch_regression_setup_rst_flip"
+        self.golden_data_path = self.path / "golden_data" / "regression_setup_rst_flip"
+
+    def setup(self):
+        self.ini_path()
+        shutil.copy(self.golden_data_path / "3V6Z_A.pdb", self.test_path)
+        shutil.copy(self.golden_data_path / "3V6Z_B.pdb", self.test_path)
+        shutil.copy(self.golden_data_path / "restraints.list", self.test_path)
+
+    def teardown(self):
+        self.clean_path()
+
+    def test_lightdock_setup_automatic(self):
+        os.chdir(self.test_path)
+
+        command = "lightdock3_setup.py 3V6Z_A.pdb 3V6Z_B.pdb --noh --noxt -anm -flip "
+        command += "-rst restraints.list >> test_lightdock.out"
+        os.system(command)
+
+        assert filecmp.cmp(
+            self.golden_data_path / "init" / "swarm_centers.pdb",
+            self.test_path / "init" / "swarm_centers.pdb",
+        )
+        assert filecmp.cmp(
+            self.golden_data_path / "setup.json", self.test_path / "setup.json"
+        )
+        assert filecmp.cmp(
+            self.golden_data_path / "init" / "initial_positions_0.dat",
+            self.test_path / "init" / "initial_positions_0.dat",
+        )
