@@ -6,21 +6,20 @@ from nose.tools import assert_almost_equals
 
 
 class TestJ2:
-
-    def setUp(self):
+    def __init__(self):
         self.expected_values = [
             [50, 51.25, 25, 51.25, 50],
             [51.25, 52.5, 26.25, 52.5, 51.25],
             [25, 26.25, 0, 26.25, 25],
             [51.25, 52.5, 26.25, 52.5, 51.25],
-            [50, 51.25, 25, 51.25, 50]
-            ]
+            [50, 51.25, 25, 51.25, 50],
+        ]
 
-    def tearDown(self):
-        pass
-    
     def test_compute_J1_matrix(self):
         j2 = J2()
         for i in range(5):
             for j in range(5):
-                assert_almost_equals(self.expected_values[i][j], j2(Coordinates([-5.0+j*2.5, -5.0+i*2.5])))
+                assert_almost_equals(
+                    self.expected_values[i][j],
+                    j2(Coordinates([-5.0 + j * 2.5, -5.0 + i * 2.5])),
+                )
