@@ -15,6 +15,7 @@ from lightdock.prep.poses import (
     populate_poses,
     calculate_initial_poses,
     apply_restraints,
+    mirror_vector,
 )
 from lightdock.mathutil.cython.quaternion import Quaternion
 from lightdock.mathutil.lrandom import MTGenerator
@@ -101,6 +102,8 @@ class TestPoses:
         assert q in (e1, e2)
 
     def test_get_quaternion_for_restraint1(self):
+        seed = 1984
+        number_generator = MTGenerator(seed)
         # Origin is 0,0,0
         # Ligand center
         l_center = [-5.0, 5.0, -5.0]
@@ -120,6 +123,7 @@ class TestPoses:
             l_center[2],  # translation
             [0.0, 0.0, 0.0],  # receptor translation
             [5.0, -5.0, 5.0],  # ligand translation
+            number_generator,
         )
 
         e = Quaternion(w=0.14518697, x=0.19403814, y=-0.58211441, z=-0.77615254)
@@ -127,6 +131,8 @@ class TestPoses:
         assert e == q
 
     def test_get_quaternion_for_restraint2(self):
+        seed = 1984
+        number_generator = MTGenerator(seed)
         # Origin is 0,0,0
         # Ligand center
         l_center = [-5.0, 5.0, -5.0]
@@ -146,6 +152,7 @@ class TestPoses:
             l_center[2],  # translation
             [0.0, 0.0, 0.0],  # receptor translation
             [5.0, -5.0, 5.0],  # ligand translation
+            number_generator,
         )
 
         e = Quaternion(0.10977233, -0.44451098, -0.88902195, 0.0)
@@ -153,6 +160,8 @@ class TestPoses:
         assert e == q
 
     def test_get_quaternion_for_restraint2d(self):
+        seed = 1984
+        number_generator = MTGenerator(seed)
         # Origin is 0,0,0
         # Ligand center
         l_center = [5.0, 5.0, 0.0]
@@ -172,6 +181,7 @@ class TestPoses:
             l_center[2],  # translation
             [0.0, 0.0, 0.0],  # receptor translation
             [5.0, 5.0, 0.0],  # ligand translation
+            number_generator,
         )
 
         e = Quaternion(0.16018224, 0.0, 0.0, -0.98708746)
@@ -179,6 +189,8 @@ class TestPoses:
         assert e == q
 
     def test_get_quaternion_for_restraint2d_different_quadrant(self):
+        seed = 1984
+        number_generator = MTGenerator(seed)
         # Origin is 0,0,0
         # Ligand center
         l_center = [5.0, -5.0, 0.0]
@@ -198,6 +210,7 @@ class TestPoses:
             l_center[2],  # translation
             [0.0, 0.0, 0.0],  # receptor translation
             [5.0, -5.0, 0.0],  # ligand translation
+            number_generator,
         )
 
         e = Quaternion(0.07088902, 0.0, 0.0, -0.99748421)
@@ -580,7 +593,7 @@ class TestPoses:
         ]
 
         new_centers = apply_restraints(
-            swarm_centers, receptor_restraints, [], distance_cutoff, translation
+            swarm_centers, receptor_restraints, [], distance_cutoff, translation, STARTING_POINTS_SEED
         )
 
         assert np.allclose(expected_new_centers, new_centers)
@@ -634,6 +647,7 @@ class TestPoses:
             blocking_restraints,
             distance_cutoff,
             translation,
+            STARTING_POINTS_SEED,
         )
 
         assert np.allclose(expected_new_centers, new_centers)
@@ -678,7 +692,20 @@ class TestPoses:
         ]
 
         new_centers = apply_restraints(
-            swarm_centers, [], blocking_restraints, distance_cutoff, translation
+            swarm_centers, [], blocking_restraints, distance_cutoff, translation, STARTING_POINTS_SEED
         )
 
         assert np.allclose(expected_new_centers, new_centers)
+
+    def test_mirror_vector(self):
+        v = np.array([2.0, 2.0, 2.0])
+
+        # Mirror the y axis 180 degrees
+        axis = np.array([0.0, 1.0, 0.0])
+        v_mirrored = mirror_vector(v, axis)
+        assert np.allclose(np.array([-2.0, 2.0, -2.0]), v_mirrored)
+
+        # Mirror the x axis 180 degrees
+        axis = np.array([1.0, 0.0, 0.0])
+        v_mirrored = mirror_vector(v, axis)
+        assert np.allclose(np.array([2.0, -2.0, -2.0]), v_mirrored)
